package com.cultural.heritage.listener;


import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.constant.MqConstant;
import com.cultural.heritage.constant.OrderStatusConstant;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.model.entity.ClothesRentOrder;
import com.cultural.heritage.service.order.ClothesRentOrderService;
import com.cultural.heritage.utils.MultiDelayMessage;
import jakarta.annotation.Resource;
import org.springframework.amqp.rabbit.annotation.Exchange;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.QueueBinding;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.stereotype.Component;

@Component
public class ClothesRentOrderStatusListener {


    @Resource
    private ClothesRentOrderService clothesRentOrderService;


    @Resource
    private RabbitTemplate rabbitTemplate;



    @RabbitListener(bindings = @QueueBinding(
            value = @Queue(MqConstant.DELAY_CLOTHES_RENT_ORDER_QUEUE),
            exchange = @Exchange(name = MqConstant.DELAY_EXCHANGE, delayed = "true"),
            key = MqConstant.DELAY_CLOTHES_RENT_ORDER_ROUTING_KEY
    ))
    public void listenDelayMessage(MultiDelayMessage<Long> msg) {
        System.out.println("\n\n\n\n\nClothesRentOrderStatusListener.listenerDelayMessage msg-------------------------------->：" + msg);
        // 1.获取消息中的订单id
        Long orderId = msg.getData();
        // 2.查询订单，判断状态是否为待支付
        ClothesRentOrder clothesRentOrder = clothesRentOrderService.getById(orderId);
        // 订单不存在或者订单已经支付
        if (clothesRentOrder == null || !clothesRentOrder.getOrderStatus().equals(OrderStatusConstant.PENDING_PAYMENT)) {
            return ;
        }
        // 3.订单未支付，判断是否还有剩余延时时间
        if (msg.hasNextDelay()) {
            // 有延迟时间，需要重发延迟消息，先获取延迟时间的int值
            // 发送延时消息
            int delayValue = msg.removeNextDelay().intValue();
            rabbitTemplate.convertAndSend(MqConstant.DELAY_EXCHANGE,
                    MqConstant.DELAY_CLOTHES_RENT_ORDER_ROUTING_KEY, msg, message -> {
                        // 添加延迟消息属性
                        message.getMessageProperties().setDelay(delayValue);
                        return message;
                    });
            return ;
        }
        // 没有剩余延时时间，说明订单超时未支付，需取消订单
        UpdateWrapper<ClothesRentOrder> updateWrapper = new UpdateWrapper<>();
        updateWrapper.eq("id", orderId).set("orderStatus", OrderStatusConstant.TRANSACTION_CLOSED);
        boolean update = clothesRentOrderService.update(updateWrapper);
        ThrowUtils.throwIf(!update, ErrorCode.OPERATION_ERROR, "订单状态更新失败");

    }

}
