package com.cultural.heritage.model.dto.good.service;

import com.cultural.heritage.model.dto.appointment.AppointmentDateAddRequest;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

@Data
@Schema(description = "服务类商品添加请求体", requiredProperties = {"name", "price", "goodImg", "intro", "richText", "label", "appointmentDateAddRequestList"})
public class ServiceGoodAddRequest implements Serializable {

    /**
     * 商品名
     */
    @Schema(description = "商品名", example = "非遗香囊")
    private String name;

    /**
     * 商品价格
     */
    @Schema(description = "商品价格", example = "20.00")
    private BigDecimal price;

    /**
     * 商品图片
     */
    @Schema(description = "商品图片", example = "https://xxx/xxx.jpg")
    private String goodImg;

    /**
     * 商品简介
     */
    @Schema(description = "商品简介", example = "传承千年文化，守护健康美好")
    private String intro;


    /**
     * 商品详情（富文本）
     */
    @Schema(description = "商品详情（富文本）", example = "<p></p>")
    private String richText;


    /**
     * 商品标签
     */
    @Schema(description = "商品标签", example = "亲情;送礼;材料包")
    private String label;


    /**
     * 未来的预约详情
     */
    @Schema(description = "未来的预约详情")
    private List<AppointmentDateAddRequest> appointmentDateAddRequestList;



    @Serial
    private static final long serialVersionUID = 1L;
}
