package com.cultural.heritage.service.good.impl;

import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.model.entity.Festival;
import com.cultural.heritage.service.good.FestivalService;
import jakarta.annotation.Resource;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class FestivalServiceImpl implements FestivalService {


    @Resource(name = "festivalRedisTemplate")
    private RedisTemplate<String, Festival> redisTemplate;


    // 节日集合的键
    private static final String FESTIVAL_KEY = "festivalList";


    /**
     * 根据节日名称获取URL
     */
    @Override
    public String getUrlByFestivalName(String festivalName) {
        // 获取 Redis 中所有的节日数据
        List<Festival> festivalList = redisTemplate.opsForList().range(FESTIVAL_KEY, 0, -1);
        if (festivalList == null || festivalList.isEmpty()) {
            throw new BusinessException(ErrorCode.OPERATION_ERROR, "节日列表为空");
        }

        // 遍历查找匹配的节日
        for (Festival festival : festivalList) {
            if (festival.getName().equals(festivalName)) {
                return festival.getUrl(); // 返回对应的 URL
            }
        }
        return null;
    }
}
