package com.cultural.heritage.service.order.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.constant.MqConstant;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.mapper.ClothesRentOrderMapper;
import com.cultural.heritage.model.dto.clothesRentOrder.ClothesRentOrderQueryRequest;
import com.cultural.heritage.model.dto.clothesRentOrder.ClothesRentOrderAddRequest;
import com.cultural.heritage.model.entity.ClothesRentOrder;
import com.cultural.heritage.service.order.ClothesRentOrderService;
import com.cultural.heritage.utils.MultiDelayMessage;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class ClothesRentOrderServiceImpl extends ServiceImpl<ClothesRentOrderMapper, ClothesRentOrder> implements ClothesRentOrderService {


    @Resource
    private RabbitTemplate rabbitTemplate;


    /**
     * 获取查询条件
     */
    @Override
    public QueryWrapper<ClothesRentOrder> getQueryWrapper(ClothesRentOrderQueryRequest clothesRentOrderQueryRequest) {
        String orderNumber = clothesRentOrderQueryRequest.getOrderNumber();
        String orderStatus = clothesRentOrderQueryRequest.getOrderStatus();
        String name = clothesRentOrderQueryRequest.getName();
        String phone = clothesRentOrderQueryRequest.getPhone();
        QueryWrapper<ClothesRentOrder> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtils.isNotBlank(orderNumber), "orderNumber", orderNumber);
        queryWrapper.eq(StringUtils.isNotBlank(orderStatus), "orderStatus", orderStatus);
        queryWrapper.like(StringUtils.isNotBlank(name), "JSON_UNQUOTE(JSON_EXTRACT(contactsSnapshot, '$.name'))", name);
        queryWrapper.eq(StringUtils.isNotBlank(phone), "JSON_UNQUOTE(JSON_EXTRACT(contactsSnapshot, '$.phone'))", phone);
        return queryWrapper;
    }


    /**
     * 校验
     */
    @Override
    public void validClothesRentOrder(ClothesRentOrderAddRequest clothesRentOrderAddRequest) {
        Long clothesId = clothesRentOrderAddRequest.getClothesId();
        Long contactsId = clothesRentOrderAddRequest.getContactsId();
        Integer rentDays = clothesRentOrderAddRequest.getRentDays();
        ThrowUtils.throwIf(ObjectUtils.anyNull(clothesId, contactsId, rentDays), ErrorCode.PARAMS_ERROR);
    }



    /**
     * 向消息队列中发送订单创建的消息
     */
    @Override
    public void sendClothesRentOrderMessage(Long orderId) {
        // 复制 DELAY_MILLIS 到一个新的 ArrayList
        List<Long> newDelayMillis = new ArrayList<>(MqConstant.DELAY_MILLIS);
        // 延迟检查订单状态信息
        MultiDelayMessage<Long> msg = new MultiDelayMessage<>(orderId, newDelayMillis);
        int delayValue = msg.removeNextDelay().intValue();
        rabbitTemplate.convertAndSend(MqConstant.DELAY_EXCHANGE,
                MqConstant.DELAY_CLOTHES_RENT_ORDER_ROUTING_KEY, msg, message -> {
                    // 添加延迟消息属性
                    message.getMessageProperties().setDelay(delayValue);
                    return message;
                });
    }


}
